# Vision6D

[![PyPI version](https://badge.fury.io/py/vision6D.svg)](https://badge.fury.io/py/vision6D)
[![License](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)

> Vision6D is a visualization tool to provide a convinent way to create ground truth 6D pose for 6D pose estimation related projects.

## Installation

Install the package using pip:

```shell
pip install vision6D
```

## Usage
```python
import vision6D as vis

# Load the interactive window
vis.exe()
```

Usage example shown below to register computer monitor model to an image

![example](https://github.com/ykzzyk/vision6D/assets/55161270/b6e4b0f6-ac51-416a-a63d-0aa0de2793d0)

## License
This project is licensed under the MIT License.

## Contact
If you have further question, you can either open a issue on GitHub or directly connect me via email yike.zhang@vanderbilt.edu
